//
// Copyright (c) 2010 Exar Corporation.  All rights reserved.
//

/*++


Module Name:

    xrpci.h

Abstract:

    Exar PCI UART card enumerator device driver

Notes:

	This driver loads to any of the Exar PCI/PCIe cards (0x158/154/152/0x258/0x254/0x252/0x358/0x354/0x352 PIDs) and 
	enumerates each port on the card with the proper Memory and interrupt
	resources. This can be considered as a Bus Driver for the card.

--*/

#define MAX_PORTS	32 // some safe number. If your platform has more than 32 Exar PCI ports, update it here

typedef struct __XRPCI_INFO 
{
    // hardware specific fields
    DWORD       dwInterfaceType;   // @filed IO Interface (bus) type
	DWORD       dwBusNumber;		// @field PCI bus number.
    DWORD       dwMemBase;          // @field Memory Base Address - unmapped
    DWORD       dwMemLen;           // @field Memory Length
	DWORD		dwIrq;				// IRQ associated with the device
    DWORD       dwSysIntr;         // @field System Interrupt number for this peripheral
    DWORD       dwDevIndex;        // @field Index of device        
	DWORD       dwDeviceId;        // EXAR PCI device ID - 0x158/0x154/0x154/0x258/0x254/0x252
	DWORD		dwTotalPortsActivated;
	HANDLE		hDevice[MAX_PORTS];

} XRPCI_INFO, *PXRPCI_INFO;


// Here are the names of the values stored in the registry
#define PC_REG_DEVINDEX_VAL_NAME TEXT("DeviceArrayIndex") 
#define PC_REG_DEVINDEX_VAL_LEN  sizeof( DWORD )
#define PC_REG_REGSTRIDE_VAL_NAME TEXT("RegStride")
#define PC_REG_REGSTRIDE_VAL_LEN  sizeof( DWORD )


BOOL
XRPCI_GetRegistryData(PXRPCI_INFO pHWHead, LPCTSTR regKeyPath);
